@@ -1,3 +1,4 @@
+from django.contrib.auth import get_user_model
 from rest_framework import serializers
 
 
@@ -7,6 +8,20 @@ class GetTokenSerializer(serializers.Serializer):
 
 
 class RefreshTokenSerializer(serializers.Serializer):
-    username = serializers.CharField(required=True, write_only=True)
-    password = serializers.CharField(required=True, write_only=True)
     refresh_token = serializers.CharField(required=True, write_only=True)
+
+
+class KeycloakUserAutoIdSerializer(serializers.ModelSerializer):
+    """
+    Serializer for the user endpoint
+    """
+
+    class Meta:
+        model = get_user_model()
+        fields = (
+            "id",
+            "username",
+            "first_name",
+            "last_name",
+            "email",
+        )
