@@ -7,14 +7,13 @@ from django_keycloak.keycloak import Connect
 
 
 class Command(BaseCommand):
-    help = 'Synchronize users with keycloak'
+    help = "Synchronize users with keycloak"
 
     def handle(self, *args, **options):
         keycloak = Connect()
         User = get_user_model()
 
-        remote_users = set([user.get('id') for user in keycloak.get_users(
-            keycloak.get_token())])
+        remote_users = set([user.get("id") for user in keycloak.get_users()])
         local_users = set(str(_u.id) for _u in User.objects.all())
 
         users_to_remove = local_users.difference(remote_users)
@@ -23,6 +22,8 @@ class Command(BaseCommand):
         # Delete users that are no longer in keycloak
         User.objects.filter(id__in=list(users_to_remove)).delete()
 
-        log.info("Removed {} users".format(len(users_to_remove)),
-                 "and there are {} new users in keycloak that are not"
-                 " locally".format(len(users_to_add)))
+        log.info(
+            "Removed {} users".format(len(users_to_remove)),
+            "and there are {} new users in keycloak that are not"
+            " locally".format(len(users_to_add)),
+        )
